# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

accessKey: Optional[str]
"""
The Scaleway access key.
"""

apiUrl: Optional[str]
"""
The Scaleway API URL to use.
"""

organizationId: Optional[str]
"""
The Scaleway organization ID.
"""

profile: Optional[str]
"""
The Scaleway profile to use.
"""

projectId: Optional[str]
"""
The Scaleway project ID.
"""

region: Optional[str]
"""
The region you want to attach the resource to
"""

secretKey: Optional[str]
"""
The Scaleway secret Key.
"""

zone: Optional[str]
"""
The zone you want to attach the resource to
"""

