# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DocumentdbPrivateNetworkEndpointArgs', 'DocumentdbPrivateNetworkEndpoint']

@pulumi.input_type
class DocumentdbPrivateNetworkEndpointArgs:
    def __init__(__self__, *,
                 instance_id: pulumi.Input[str],
                 private_network: Optional[pulumi.Input['DocumentdbPrivateNetworkEndpointPrivateNetworkArgs']] = None,
                 region: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a DocumentdbPrivateNetworkEndpoint resource.
        :param pulumi.Input[str] instance_id: UUID of the documentdb instance.
        :param pulumi.Input['DocumentdbPrivateNetworkEndpointPrivateNetworkArgs'] private_network: The private network specs details. This is a list with maximum one element and supports the following attributes:
        :param pulumi.Input[str] region: The region of the endpoint.
               
               
               > **NOTE:** Please calculate your host IP.
               using cirhost. Otherwise, lets IPAM service
               handle the host IP on the network.
        """
        pulumi.set(__self__, "instance_id", instance_id)
        if private_network is not None:
            pulumi.set(__self__, "private_network", private_network)
        if region is not None:
            pulumi.set(__self__, "region", region)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Input[str]:
        """
        UUID of the documentdb instance.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="privateNetwork")
    def private_network(self) -> Optional[pulumi.Input['DocumentdbPrivateNetworkEndpointPrivateNetworkArgs']]:
        """
        The private network specs details. This is a list with maximum one element and supports the following attributes:
        """
        return pulumi.get(self, "private_network")

    @private_network.setter
    def private_network(self, value: Optional[pulumi.Input['DocumentdbPrivateNetworkEndpointPrivateNetworkArgs']]):
        pulumi.set(self, "private_network", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[str]]:
        """
        The region of the endpoint.


        > **NOTE:** Please calculate your host IP.
        using cirhost. Otherwise, lets IPAM service
        handle the host IP on the network.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "region", value)


@pulumi.input_type
class _DocumentdbPrivateNetworkEndpointState:
    def __init__(__self__, *,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 private_network: Optional[pulumi.Input['DocumentdbPrivateNetworkEndpointPrivateNetworkArgs']] = None,
                 region: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering DocumentdbPrivateNetworkEndpoint resources.
        :param pulumi.Input[str] instance_id: UUID of the documentdb instance.
        :param pulumi.Input['DocumentdbPrivateNetworkEndpointPrivateNetworkArgs'] private_network: The private network specs details. This is a list with maximum one element and supports the following attributes:
        :param pulumi.Input[str] region: The region of the endpoint.
               
               
               > **NOTE:** Please calculate your host IP.
               using cirhost. Otherwise, lets IPAM service
               handle the host IP on the network.
        """
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if private_network is not None:
            pulumi.set(__self__, "private_network", private_network)
        if region is not None:
            pulumi.set(__self__, "region", region)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[str]]:
        """
        UUID of the documentdb instance.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="privateNetwork")
    def private_network(self) -> Optional[pulumi.Input['DocumentdbPrivateNetworkEndpointPrivateNetworkArgs']]:
        """
        The private network specs details. This is a list with maximum one element and supports the following attributes:
        """
        return pulumi.get(self, "private_network")

    @private_network.setter
    def private_network(self, value: Optional[pulumi.Input['DocumentdbPrivateNetworkEndpointPrivateNetworkArgs']]):
        pulumi.set(self, "private_network", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[str]]:
        """
        The region of the endpoint.


        > **NOTE:** Please calculate your host IP.
        using cirhost. Otherwise, lets IPAM service
        handle the host IP on the network.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "region", value)


class DocumentdbPrivateNetworkEndpoint(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 private_network: Optional[pulumi.Input[Union['DocumentdbPrivateNetworkEndpointPrivateNetworkArgs', 'DocumentdbPrivateNetworkEndpointPrivateNetworkArgsDict']]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Creates and manages Scaleway Database Private Network Endpoint.

        ## Example Usage

        ### Example Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        pn = scaleway.VpcPrivateNetwork("pn", name="my_private_network")
        instance = scaleway.DocumentdbInstance("instance",
            name="test-document_db-basic",
            node_type="docdb-play2-pico",
            engine="FerretDB-1",
            user_name="my_initial_user",
            password="thiZ_is_v&ry_s3cret",
            volume_size_in_gb=20)
        main = scaleway.DocumentdbPrivateNetworkEndpoint("main",
            instance_id=instance.id,
            private_network={
                "ip_net": "172.16.32.3/22",
                "id": pn.id,
            },
            opts = pulumi.ResourceOptions(depends_on=[pn]))
        ```

        ## Import

        Database Instance Endpoint can be imported using the `{region}/{endpoint_id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:index/documentdbPrivateNetworkEndpoint:DocumentdbPrivateNetworkEndpoint end fr-par/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] instance_id: UUID of the documentdb instance.
        :param pulumi.Input[Union['DocumentdbPrivateNetworkEndpointPrivateNetworkArgs', 'DocumentdbPrivateNetworkEndpointPrivateNetworkArgsDict']] private_network: The private network specs details. This is a list with maximum one element and supports the following attributes:
        :param pulumi.Input[str] region: The region of the endpoint.
               
               
               > **NOTE:** Please calculate your host IP.
               using cirhost. Otherwise, lets IPAM service
               handle the host IP on the network.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DocumentdbPrivateNetworkEndpointArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates and manages Scaleway Database Private Network Endpoint.

        ## Example Usage

        ### Example Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        pn = scaleway.VpcPrivateNetwork("pn", name="my_private_network")
        instance = scaleway.DocumentdbInstance("instance",
            name="test-document_db-basic",
            node_type="docdb-play2-pico",
            engine="FerretDB-1",
            user_name="my_initial_user",
            password="thiZ_is_v&ry_s3cret",
            volume_size_in_gb=20)
        main = scaleway.DocumentdbPrivateNetworkEndpoint("main",
            instance_id=instance.id,
            private_network={
                "ip_net": "172.16.32.3/22",
                "id": pn.id,
            },
            opts = pulumi.ResourceOptions(depends_on=[pn]))
        ```

        ## Import

        Database Instance Endpoint can be imported using the `{region}/{endpoint_id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:index/documentdbPrivateNetworkEndpoint:DocumentdbPrivateNetworkEndpoint end fr-par/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param DocumentdbPrivateNetworkEndpointArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DocumentdbPrivateNetworkEndpointArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 private_network: Optional[pulumi.Input[Union['DocumentdbPrivateNetworkEndpointPrivateNetworkArgs', 'DocumentdbPrivateNetworkEndpointPrivateNetworkArgsDict']]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DocumentdbPrivateNetworkEndpointArgs.__new__(DocumentdbPrivateNetworkEndpointArgs)

            if instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'instance_id'")
            __props__.__dict__["instance_id"] = instance_id
            __props__.__dict__["private_network"] = private_network
            __props__.__dict__["region"] = region
        super(DocumentdbPrivateNetworkEndpoint, __self__).__init__(
            'scaleway:index/documentdbPrivateNetworkEndpoint:DocumentdbPrivateNetworkEndpoint',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            instance_id: Optional[pulumi.Input[str]] = None,
            private_network: Optional[pulumi.Input[Union['DocumentdbPrivateNetworkEndpointPrivateNetworkArgs', 'DocumentdbPrivateNetworkEndpointPrivateNetworkArgsDict']]] = None,
            region: Optional[pulumi.Input[str]] = None) -> 'DocumentdbPrivateNetworkEndpoint':
        """
        Get an existing DocumentdbPrivateNetworkEndpoint resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] instance_id: UUID of the documentdb instance.
        :param pulumi.Input[Union['DocumentdbPrivateNetworkEndpointPrivateNetworkArgs', 'DocumentdbPrivateNetworkEndpointPrivateNetworkArgsDict']] private_network: The private network specs details. This is a list with maximum one element and supports the following attributes:
        :param pulumi.Input[str] region: The region of the endpoint.
               
               
               > **NOTE:** Please calculate your host IP.
               using cirhost. Otherwise, lets IPAM service
               handle the host IP on the network.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DocumentdbPrivateNetworkEndpointState.__new__(_DocumentdbPrivateNetworkEndpointState)

        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["private_network"] = private_network
        __props__.__dict__["region"] = region
        return DocumentdbPrivateNetworkEndpoint(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[str]:
        """
        UUID of the documentdb instance.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="privateNetwork")
    def private_network(self) -> pulumi.Output[Optional['outputs.DocumentdbPrivateNetworkEndpointPrivateNetwork']]:
        """
        The private network specs details. This is a list with maximum one element and supports the following attributes:
        """
        return pulumi.get(self, "private_network")

    @property
    @pulumi.getter
    def region(self) -> pulumi.Output[str]:
        """
        The region of the endpoint.


        > **NOTE:** Please calculate your host IP.
        using cirhost. Otherwise, lets IPAM service
        handle the host IP on the network.
        """
        return pulumi.get(self, "region")

